==> spacy_api-0.0.15.tar.gz: spacy_api-0.0.15/setup.py <==
from setuptools import find_packages
from setuptools import setup

MAJOR_VERSION = '0'
MINOR_VERSION = '0'
MICRO_VERSION = '15'
VERSION = "{}.{}.{}".format(MAJOR_VERSION, MINOR_VERSION, MICRO_VERSION)

setup(name='spacy_api',
      version=VERSION,
      description="Server/Client around Spacy to load only once",
      author='Pascal van Kooten',
      url='https://github.com/kootenpv/spacy_api',
      author_email='kootenpv@gmail.com',
      entry_points={
          'console_scripts': ['spacy = spacy_api.__main__:main']
      },
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Environment :: Console',
          'Intended Audience :: Developers',
          'Intended Audience :: Science/Research',
          'License :: OSI Approved :: MIT License',
          'Operating System :: POSIX :: Linux',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: Microsoft :: Windows',
          'Programming Language :: Cython',
          'Programming Language :: Python :: 2.6',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3.3',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Topic :: Scientific/Engineering'
      ],
      extras_require={
          'server': ['spacy', 'flask'],
          'client': ['requests', 'numpy'],
          'all': ['requests', 'flask', 'spacy', 'numpy']
      },
      license='MIT',
      packages=find_packages(),
      zip_safe=False,
      platforms='any')

==> spacy_api-0.2.19.tar.gz: spacy_api-0.2.19/setup.py <==
from setuptools import find_packages
from setuptools import setup

MAJOR_VERSION = '0'
MINOR_VERSION = '2'
MICRO_VERSION = '19'
VERSION = "{}.{}.{}".format(MAJOR_VERSION, MINOR_VERSION, MICRO_VERSION)

setup(name='spacy_api',
      version=VERSION,
      description="Server/Client around Spacy to load only once",
      author='Pascal van Kooten',
      url='https://github.com/kootenpv/spacy_api',
      author_email='kootenpv@gmail.com',
      entry_points={
          'console_scripts': ['spacy = spacy_api.__main__:main']
      },
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Environment :: Console',
          'Intended Audience :: Developers',
          'Intended Audience :: Science/Research',
          'License :: OSI Approved :: MIT License',
          'Operating System :: POSIX :: Linux',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: Microsoft :: Windows',
          'Programming Language :: Cython',
          'Programming Language :: Python :: 2.6',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3.3',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Topic :: Scientific/Engineering'
      ],
      extras_require={
          'server': ['spacy', 'mprpc'],
          'client': ['mprpc', 'numpy'],
          'all': ['mprpc', 'spacy', 'numpy']
      },
      license='MIT',
      packages=find_packages(),
      zip_safe=False,
      platforms='any')
